
# Type: chemical to pathway association_object




URI: [biolink:chemical_to_pathway_association_object](https://w3id.org/biolink/vocab/chemical_to_pathway_association_object)


## Domain and Range

[ChemicalToPathwayAssociation](ChemicalToPathwayAssociation.md) ->  <sub>REQ</sub> [Pathway](Pathway.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [ChemicalToPathwayAssociation](ChemicalToPathwayAssociation.md)
